package org.foxarmy.barcodescannerforemployees

import okhttp3.*
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.RequestBody.Companion.asRequestBody
import org.foxarmy.barcodescannerforemployees.dataclasses.AbstractProduct
import java.io.File
import kotlin.concurrent.thread

class Net {
    var language = "en-US"

    fun requestProductFromOnlineDB(barcode: String): String {
        var response = ""
        thread {
            val url = "https://ean-online.ru/match.php"

            val client = OkHttpClient()

            val formBody = FormBody.Builder()
            formBody.add("barcode", barcode)
            val body = formBody.build()
            val request = Request.Builder()
                .url(url)
                .post(body)
                .addHeader("referer", "https://ean-online.ru")
                .addHeader("accept-language", language)
                .build()

            response = client.newCall(request).execute().body!!.string()
        }.join()

        return if (response == "") {
            "Not found 404"
        } else {
            response
        }
    }

    fun registerAccount(server: String, username: String, password: String): String {
        var token = ""
        lateinit var response: Response
        thread {
            val client = OkHttpClient()

            val formBody = FormBody.Builder()
            formBody.add("username", username)
            formBody.add("password", password)
            val body = formBody.build()

            val request = Request.Builder()
                .url("https://$server/api/user/register")
                .post(body)
                .addHeader("content-type", "application/x-www-form-urlencoded")
                .addHeader("accept-language", language)
                .build()

            response = client.newCall(request).execute()
        }.join()

        return response.body!!.string()
    }

    fun login(server: String, username: String, password: String): String {
        lateinit var response: Response
        thread {
            val client = OkHttpClient()

            val formBody = FormBody.Builder()
            formBody.add("username", username)
            formBody.add("password", password)
            val body = formBody.build()

            val requestLogin = Request.Builder()
                .url("https://$server/api/user/login")
                .post(body)
                .addHeader("content-type", "application/x-www-form-urlencoded")
                .addHeader("accept-language", language)
                .build()
            response = client.newCall(requestLogin).execute()
        }.join()

        return response.body!!.string()
    }

    fun uploadAbstractProduct(server: String, groupId: Int, abstractProduct: AbstractProduct, imageFile: File, token: String): String {
        lateinit var response: Response

        thread {
            val client = OkHttpClient()

            val body = MultipartBody.Builder()
            body.setType("multipart/form-data".toMediaType())
            body.addFormDataPart("file", imageFile.name, imageFile.asRequestBody("image/png".toMediaTypeOrNull()))
            body.addFormDataPart("groupId", groupId.toString())
            body.addFormDataPart("localId", abstractProduct.id.toString())
            body.addFormDataPart("barcode", abstractProduct.barcode)
            body.addFormDataPart("name", abstractProduct.name)
            body.addFormDataPart("net_weight", abstractProduct.netWeight.toString())
            body.addFormDataPart("category", abstractProduct.category.toString())
            body.addFormDataPart("unit", abstractProduct.unit.toString())

            val requestBody = body.build()

            val request = Request.Builder()
                .url("https://$server/api/abstractproduct/create")
                .post(requestBody)
                .addHeader("Authorization", "Bearer $token")
                .addHeader("accept-language", language)
                .build()

            response = client.newCall(request).execute()
        }.join()

        val responseText = response.body!!.string()

        return responseText
    }

    fun changeUsername(server: String, token: String, newUsername: String): String {

        lateinit var response: Response

        thread {
            val client = OkHttpClient()

            val body = FormBody.Builder()
            body.add("username", newUsername)

            val requestBody = body.build()

            val request = Request.Builder().url("https://$server/api/user/changeUsername")
                .post(requestBody)
                .addHeader("Authorization", "Bearer $token")
                .addHeader("accept-language", language)
                .build()
            response = client.newCall(request).execute()
        }.join()

        val responseText = response.body!!.string()

        return responseText
    }

    fun changePassword(server: String, token: String, newPassword: String): String {

        lateinit var response: Response

        thread {
            val client = OkHttpClient()

            val body = FormBody.Builder()
            body.add("password", newPassword)

            val requestBody = body.build()

            val request = Request.Builder().url("https://$server/api/user/changePassword")
                .post(requestBody)
                .addHeader("Authorization", "Bearer $token")
                .addHeader("accept-language", language)
                .build()
            response = client.newCall(request).execute()
        }.join()

        val responseText = response.body!!.string()

        return responseText
    }
}