package org.foxarmy.barcodescannerforemployees.activities

import android.content.Intent
import android.os.Bundle
import android.widget.ArrayAdapter
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.security.crypto.EncryptedSharedPreferences
import androidx.security.crypto.MasterKeys
import org.foxarmy.barcodescannerforemployees.Net
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.databinding.ActivityLoginBinding

class LoginActivity : AppCompatActivity() {

    private lateinit var binding: ActivityLoginBinding;

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityLoginBinding.inflate(layoutInflater);
        setContentView(binding.root)

        fillUpLanguagesSpinner()

        val masterKeyAlias = MasterKeys.getOrCreate(MasterKeys.AES256_GCM_SPEC)

        val sharedPreferences = EncryptedSharedPreferences.create(
            "sensitive",
            masterKeyAlias,
            applicationContext,
            EncryptedSharedPreferences.PrefKeyEncryptionScheme.AES256_SIV,
            EncryptedSharedPreferences.PrefValueEncryptionScheme.AES256_GCM
        )

        binding.loginButton.setOnClickListener {
            val server = binding.serverTextEdit.text.toString()
            val username = binding.usernameTextEdit.text.toString()
            val password = binding.passwordTextEdit.text.toString()
            val language = resources.getStringArray(R.array.languages)[binding.languageSpinner.selectedItemPosition]
            sharedPreferences.edit().putString("language", language).apply()

            val n = Net()
            n.language = language

            val response = n.login(server, username, password)
            if (response.length < 40) {
                Toast.makeText(this, response, Toast.LENGTH_SHORT).show()
            } else {
                sharedPreferences.edit().putString("token", response).apply()
                val intent = Intent(this, MainActivity::class.java)
                startActivity(intent)
                finish()
            }
        }

        binding.registerButton.setOnClickListener {
            val server = binding.serverTextEdit.text.toString()
            val username = binding.usernameTextEdit.text.toString()
            val password = binding.passwordTextEdit.text.toString()
            val language = resources.getStringArray(R.array.languages)[binding.languageSpinner.selectedItemPosition]
            sharedPreferences.edit().putString("language", language).apply()

            val n = Net()
            n.language = language

            val response = n.registerAccount(server, username, password);

            if (response.length < 40) {
                Toast.makeText(this, response, Toast.LENGTH_SHORT).show();
            } else {
                sharedPreferences.edit().putString("token", response).apply()
                sharedPreferences.edit().putString("server", server).apply()
                val intent = Intent(this, MainActivity::class.java)
                startActivity(intent)
                finish()
            }
        }
    }

    private fun fillUpLanguagesSpinner() {
        val languages = resources.getStringArray(R.array.languages)
        val arrayAdapter = ArrayAdapter(this, androidx.appcompat.R.layout.support_simple_spinner_dropdown_item, languages)
        arrayAdapter.setDropDownViewResource(androidx.appcompat.R.layout.support_simple_spinner_dropdown_item)
        binding.languageSpinner.adapter = arrayAdapter
    }

}